import {
	type Editor,
	type MarkdownView,
	type MarkdownFileInfo,
	type App,
	Notice,
} from "obsidian";
import { EditorCheckCommand } from "./Command";
import type { BookTrackerPluginSettings } from "@ui/settings";
import { STATUS_IN_PROGRESS } from "@src/const";
import moment from "@external/moment";

export class LogReadingStartedCommand extends EditorCheckCommand {
	constructor(
		private readonly app: App,
		private readonly settings: BookTrackerPluginSettings
	) {
		super("log-reading-started", "Log Reading Started");
	}

	protected check(
		_editor: Editor,
		ctx: MarkdownView | MarkdownFileInfo
	): boolean {
		return !(
			ctx.file === null ||
			this.settings.statusProperty === "" ||
			this.settings.startDateProperty === ""
		);
	}

	protected async run(
		_editor: Editor,
		ctx: MarkdownView | MarkdownFileInfo
	): Promise<void> {
		const file = ctx.file!;

		const startDate = moment().format("YYYY-MM-DD");

		this.app.fileManager.processFrontMatter(file, (fm) => {
			fm[this.settings.statusProperty] = STATUS_IN_PROGRESS;
			fm[this.settings.startDateProperty] = startDate;
		});

		new Notice("Reading started for " + file.basename);
	}
}
