import moment from "@external/moment";
import { STATUS_IN_PROGRESS, STATUS_READ, STATUS_TO_BE_READ } from "./const";
import z from "zod/v4";

export interface Author {
	name: string;
	description?: string;
}

export interface Series {
	title: string;
	position: number;
}

export interface Book {
	title: string;
	subtitle: string;
	description: string;
	authors: Author[];
	series: Series | null;
	publisher: string;
	publishedAt: Date;
	genres: string[];
	coverImageUrl: string;
	pageCount: number;
	isbn: string;
	isbn13: string;
}

export type ToBeReadState = typeof STATUS_TO_BE_READ;
export type InProgressState = typeof STATUS_IN_PROGRESS;
export type ReadState = typeof STATUS_READ;

export type ReadingState = ToBeReadState | InProgressState | ReadState;

export const BookMetadataSchema = z.object({
	title: z.string(),
	subtitle: z.string(),
	description: z.string(),
	authors: z.array(z.string()),
	seriesTitle: z.string(),
	seriesPosition: z.number(),
	startDate: z.date().transform((date) => moment(date)),
	endDate: z.date().transform((date) => moment(date)),
	status: z.enum([STATUS_TO_BE_READ, STATUS_IN_PROGRESS, STATUS_READ]),
	rating: z.number(),
	spice: z.number(),
	format: z.string(),
	source: z.array(z.string()),
	categories: z.array(z.string()),
	publisher: z.string(),
	publishDate: z.date().transform((date) => moment(date)),
	pageCount: z.number(),
	isbn: z.string(),
	coverImageUrl: z.string(),
	localCoverPath: z.string(),
});

export type BookMetadata = z.infer<typeof BookMetadataSchema>;
